package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,``@$!````+!\```````!``````````*C#````
M````0P```$``.``)`$``%@`5``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````)RD````````G*0`````````
M0`````````$````&````$+X````````0_@```````!#^````````J`0`````
M````!0````````!``````````@````8````@O@```````"#^````````(/X`
M``````#@`0```````.`!````````"``````````$````!````%@"````````
M6`(```````!8`@```````"0`````````)``````````$`````````%#E=&0$
M````D)X```````"0G@```````)">````````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````!"^````````$/X````````0_@``
M`````/`!````````\`$````````!`````````"]L:6(O;&0M;75S;"UL;V]N
M9V%R8V@V-"YS;RXQ````!````!0````#````1TY5`(&>;96\3=B&7650DR=R
M=LS%;K*9`````!$```!1````!`````@````@$!``!4`$@"@`$`2`A@"$@H$`
M`@D`!`B(@!!!N@`""`````!1````5````%<```!8````7P```&````!A````
M`````&,```!D`````````&4```!F````:```````````````SMY'+6[%WQ]K
M?YI\+L6;MB#_Y`[59-1\V7%8'+(!BV^83\.;PN4_+$+ZUX?ZH6Q@NN.2?.-'
MQ@%5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)````
M```````````````````````````````````````#``D`$!T`````````````
M```````````#``H`.%T````````````````````````#``L`D)X`````````
M```````````````#``P`:)\````````````````````````#`!`````!````
M```````````````````#`!(`L`(!```````````````````````#`!,`N`(!
M`````````````````(D"```2`````````````````````````+0!```2````
M`````````````````````%(````2`````````````````````````-4"```2
M`````````````````````````+H````1`````````````````````````(@!
M```2`````````````````````````#T````2````````````````````````
M`#(!```2`````````````````````````/$!```2````````````````````
M`````+$````2`````````````````````````,P````B````````````````
M`````````%$!```2`````````````````````````-8!```2````````````
M`````````````'<"```2`````````````````````````)D!```2````````
M`````````````````!4!```2`````````````````````````)`"```2````
M`````````````````````.`"```A`````````````````````````#<````2
M`````````````````````````-\"```1`````````````````````````,D!
M```1`````````````````````````$`!```2````````````````````````
M`!P$```B`````````````````````````&`"```2````````````````````
M`````&(````2`````````````````````````!`"```2````````````````
M`````````.$"```1`````````````````````````*(````2````````````
M`````````````#<"```2`````````````````````````!\````@````````
M`````````````````&8!```2`````````````````````````/8````@````
M`````````````````````-X"```A`````````````````````````&H````2
M`````````````````````````)H````2`````````````````````````!`!
M```2`````````````````````````%H````2````````````````````````
M`$L````2`````````````````````````!`````2````````````````````
M`````"X"```2`````````````````````````*<"```2````````````````
M`````````*@!```2`````````````````````````'D````@````````````
M`````````````*`"```2`````````````````````````%`"```2````````
M`````````````````/T!```2``````````````````````````$````2````
M`````````````````````$0````2`````````````````````````!`$```2
M`````````````````````````+T"```B`````````````````````````$("
M```2`````````````````````````)@"```2````````````````````````
M``D````1`````````````````````````!X"```2````````````````````
M`````&L````2`````````````````````````'X"```2````````````````
M`````````!@````2`````````````````````````!L!```2````````````
M`````````````/$````2`````````````````````````'4!```6````````
M`````````````````*X"```2`````````````````````````,,"```2````
M`````````````````````#D!```2`````````````````````````)4````2
M`````````````````````````*H````2`````````````````````````'``
M```2`````````````````````````%@!```2````````````````````````
M`&L"```2`````````````````````````"P!```2````````````````````
M`````-L````@`````````````````````````.<!```2````````````````
M`````````*$````2`````````````````````````.P!```2````````````
M`````````````)@#```2``D`V#0```````!`!@```````*4#```2``D`B#T`
M``````#H`````````-`"```2``D`$!T````````<`@```````!P#```2``D`
M^"<````````$`````````%$#```2``D`_"<```````"``@```````&8#```2
M``D`&#L```````!P`@```````+$#```0`!,`N`(!`````````````````#<#
M```2``D`+#$```````!L`````````%X#```2``D`F#$```````!8````````
M`'P#```2``D`5"8````````H`````````(T#```2``D`=%4```````#L!```
M`````+T#```2``D`O#,````````<`0```````.P#```0`!,`$`,!````````
M`````````/$#```2``D`?"H````````T`````````(0#```2``D`0!\`````
M```H`````````$4#```2``D`L"H```````!X`0```````"T#```1`!``0``!
M```````(`````````.4#```0`!(`N`(!`````````````````+8#```2``D`
M+!\``````````````````!D$```2``D`!%4```````!P`````````/X#```2
M``D`E#,````````H`````````,\#```2``D`?"8```````!\`0```````"($
M```2``D`8%H```````#8`@````````\#```2``D`*"P````````$!0``````
M``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?
M9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP`'5N;&EN:P!M96UM;W9E
M`'-T<FYC;7``<W1R<F-H<@!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G:7-T
M97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`=F9P<FEN=&8`<W1R8VAR`')E
M861L:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G
M:7-T97)?9G)A;65?:6YF;P!E>&ET`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]A;&QO8P!S=')C<'D`<F5A9&1I<@!S<')I;G1F`'-T
M<F1U<`!S=')T;VL`<'1H<F5A9%]A=&9O<FL`7V9I;FD`7U]L:6)C7W-T87)T
M7VUA:6X`<VYP<FEN=&8`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S
M;"UL;V]N9V%R8V@V-"YS;RXQ`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N=%]E
M>&5C`&UY7W!A<E]P;`!P87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F
M:6YD<')O9P!P87)?9&EE`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET
M`%]S=&%R=%]C`'-H85]U<&1A=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P
M`%]?8G-S7W-T87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!?961A=&$`7V5N9`!P87)?8F%S96YA;64`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<VAA7VEN:70`<VAA7V9I;F%L`"]U<W(O;&EB+W!E
M<FPU+V-O<F5?<&5R;"]#3U)%`````````!#^`````````P````````!T(```
M`````!C^`````````P`````````$(````````!```0```````P````````"`
M7@```````!@``0```````P````````#H8````````"```0```````P``````
M``#P8````````"@``0```````P````````#X8````````#```0```````P``
M````````80```````$```0```````P`````````(80```````(`"`0``````
M`P`````````0'0```````+`"`0```````P````````"P`@$``````#`"`0``
M`````@````P``````````````#@"`0```````@````T``````````````$`"
M`0```````@```!(``````````````$@"`0```````@```!P`````````````
M`%`"`0```````@```!X``````````````%@"`0```````@```"(`````````
M`````&`"`0```````@```"4``````````````&@"`0```````@```"<`````
M`````````'`"`0```````@```#(``````````````'@"`0```````@```#0`
M`````````````(@"`0```````@```#4``````````````)`"`0```````@``
M`#D``````````````)@"`0```````@```#P``````````````*`"`0``````
M"P```$,``````````````*@"`0```````@```$T``````````````%@``0``
M````!0````@``````````````&```0``````!0````D``````````````&@`
M`0``````!0````H``````````````'```0``````!0````L`````````````
M`'@``0``````!0````X``````````````(```0``````!0````\`````````
M`````(@``0``````!0```!```````````````)```0``````!0```!$`````
M`````````)@``0``````!0```!(``````````````*```0``````!0```!,`
M`````````````*@``0``````!0```!0``````````````+```0``````!0``
M`!4``````````````+@``0``````!0```!8``````````````,```0``````
M!0```!<``````````````,@``0``````!0```!@``````````````-```0``
M````!0```!H``````````````-@``0``````!0```!T``````````````.``
M`0``````!0```!\``````````````.@``0``````!0```"``````````````
M`/```0``````!0```"$``````````````/@``0``````!0```",`````````
M```````!`0``````!0```"0```````````````@!`0``````!0```"4`````
M`````````!`!`0``````!0```"8``````````````!@!`0``````!0```"D`
M`````````````"`!`0``````!0```"H``````````````"@!`0``````!0``
M`"L``````````````#`!`0``````!0```"P``````````````#@!`0``````
M!0```"T``````````````$`!`0``````!0```"X``````````````$@!`0``
M````!0```"\``````````````%`!`0``````!0```#```````````````%@!
M`0``````!0```#$``````````````&`!`0``````!0```#,`````````````
M`&@!`0``````!0```#8``````````````'`!`0``````!0```#<`````````
M`````'@!`0``````!0```#@``````````````(`!`0``````!0```#H`````
M`````````(@!`0``````!0```#L``````````````)`!`0``````!0```#T`
M`````````````)@!`0``````!0```#X``````````````*`!`0``````!0``
M`#\``````````````*@!`0``````!0```$```````````````+`!`0``````
M!0```$$``````````````+@!`0``````!0```$(``````````````,`!`0``
M````!0```$0``````````````,@!`0``````!0```$4``````````````-`!
M`0``````!0```$8``````````````-@!`0``````!0```$<`````````````
M`.`!`0``````!0```$@``````````````.@!`0``````!0```$D`````````
M`````/`!`0``````!0```$H``````````````/@!`0``````!0```$L`````
M```````````"`0``````!0```$P```````````````@"`0``````!0```$T`
M`````````````!`"`0``````!0```$X``````````````!@"`0``````!0``
M`$\``````````````"`"`0``````!0```%``````````````````````````
MS@$`'*V]$0#/X=LHK5'_`LSAVP*M!44`C"'`*.`!`$S/`0`<[Z';*.T!`$P`
M`$`#SP$`'.^!VRCM`0!,``!``\\!`!SO8=LH[0$`3```0`//`0`<[T';*.T!
M`$P``$`#SP$`'.\AVRCM`0!,``!``\\!`!SO`=LH[0$`3```0`//`0`<[^':
M*.T!`$P``$`#SP$`'._!VBCM`0!,``!``\\!`!SOH=HH[0$`3```0`//`0`<
M[X':*.T!`$P``$`#SP$`'.]AVBCM`0!,``!``\\!`!SO0=HH[0$`3```0`//
M`0`<[R':*.T!`$P``$`#SP$`'.\!VBCM`0!,``!``\\!`!SOX=DH[0$`3```
M0`//`0`<[\'9*.T!`$P``$`#SP$`'.^AV2CM`0!,``!``\\!`!SO@=DH[0$`
M3```0`//`0`<[V'9*.T!`$P``$`#SP$`'.]!V2CM`0!,``!``\\!`!SO(=DH
M[0$`3```0`//`0`<[P'9*.T!`$P``$`#SP$`'._AV"CM`0!,``!``\\!`!SO
MP=@H[0$`3```0`//`0`<[Z'8*.T!`$P``$`#SP$`'.^!V"CM`0!,``!``\\!
M`!SO8=@H[0$`3```0`//`0`<[T'8*.T!`$P``$`#SP$`'.\AV"CM`0!,``!`
M`\\!`!SO`=@H[0$`3```0`//`0`<[^'7*.T!`$P``$`#SP$`'._!URCM`0!,
M``!``\\!`!SOH=<H[0$`3```0`//`0`<[X'7*.T!`$P``$`#SP$`'.]AURCM
M`0!,``!``\\!`!SO0=<H[0$`3```0`//`0`<[R'7*.T!`$P``$`#SP$`'.\!
MURCM`0!,``!``\\!`!SOX=8H[0$`3```0`//`0`<[\'6*.T!`$P``$`#SP$`
M'.^AUBCM`0!,``!``\\!`!SO@=8H[0$`3```0`//`0`<[V'6*.T!`$P``$`#
MSP$`'.]!UBCM`0!,``!``\\!`!SO(=8H[0$`3```0`//`0`<[P'6*.T!`$P`
M`$`#SP$`'._AU2CM`0!,``!``\\!`!SOP=4H[0$`3```0`//`0`<[Z'5*.T!
M`$P``$`#SP$`'.^!U2CM`0!,``!``\\!`!SO8=4H[0$`3```0`//`0`<[T'5
M*.T!`$P``$`#SP$`'.\AU2CM`0!,``!``\\!`!SO`=4H[0$`3```0`//`0`<
M[^'4*.T!`$P``$`#SP$`'._!U"CM`0!,``!``\\!`!SOH=0H[0$`3```0`//
M`0`<[X'4*.T!`$P``$`#8X#^`F%@P2EW0,$I>"#!*7D`P2EZX,`I^`$`&@S#
MR"B,`0`FC0`5`&5`P"EF(,`I94#``F8@P`)D<,`";*#`*6UP@"G_C_U7Y@$`
M&L8@RBCD`0`:Q0`5`(3@R"C_U_Y7[`$`&HPAR2B,`0`J@"T!0/<!`!KWPLL"
M[`$`&HR!RBB-"0PX>1P`)*R)$BHD$X`"A`Q!`(P-@`.LB1(I_P?_5VY`P"CL
M`0`:CP'!*,T!`"9L'``DY"+`*8T``">M```:K6'#`HT@P"FM```:K8'#`HU@
MP"F/0,`I#02``CD/@`*'`!4`K"4!9)`-@`+.(<`"$8)```P0@`+/`0`FC0U!
M`(P%@`+O-!PXSB'``I'M_U\,@D``Y&+`*(P-00`E```:"``5`"8#%0"EH-<"
MX#`<./]#_%>`F`!`Y&+`*'J0P`+_<_U7F0`5`*0``!I%`Q4`A$#X`@!4`E2`
M@`!`Y&+`*/]S_E?_+_Y7&,/(*&V@P"@,`P`FK*4`7&%@P2AW0,$H>"#!*'K@
MP"@D`Q4`>0#!*&.`P0(@``!,]P$`&O]7_5?WPLL"Y&+`*8!H`$#_=_M7[`$`
M&HV!RBBM"0PX+@``%*VY$`"@628I_[?^4^1BP"C_<_Q7_V?_4^1"P"B`#`!`
M`)@>5/][_U.D```:10,5`(1@]@(`M`%4Y$+`*9]@_T,`>!Y4_UO_4PP0@`+_
M"_]3!`2``O\/_5?_2_M7%@`5`&0`%0!E]P88`P"#```$`%"%```DZ`$`&N<!
M`!J&(,`"Y`$`&@D`%0`(0<HHYT#)*(0`RBC_[_Q38\#_`G8@P"EV0,`"Y`$`
M&NP!`!J$(,$"C"'!`H0=`%CL`0`:C,')*(`1`$!V(,`H8T#``H`!`$QV(,`H
M8T#``B```$QCP/\"=B#`*79`P`+D`0`:[`$`&H0@P0*%(<$"I9`1`*P,20"E
M_$4`I;`0`*4$20"@'`!`[`$`&HRAR2B`$0!`=B#`*&-`P`*``0!,=B#`*&-`
MP`(@``!,8X#_`G9`P"EA8,`I=R#`*7:`P`+7`0`:[.(**H!!`$3,`0`:C`')
M*(`1`$#,`0`:A,'**/^[^5?_+_]7S`$`&HR!R2B`$0!`!`$`&H2@_0+_?_I7
M#`2``NSB"BEA8,`H=D#`*'<@P"AC@,`"(```3,P!`!J,H<HH@#D`0&/`_P)V
M```G82#`*79`P`+%`0`:!`$`&J4`RP*$H/T"_S/\5W8``"9A(,`H8T#``O__
M_E/_^_Y38P#_`F'@P"EWP,`I>*#`*7F`P"EZ8,`I>T#`*7P@P"E]```G@+P`
M0,P!`!J,8<DHG0$`)J"O`$",```HF@`5`+L`%0"9`!4`#?2``H"=`$"-$0!8
M+`<`*#D'P`*?]?]'.6L1`+<#`";@-@!`N`,5`!ST@`(F`Q4`10,5`.0"%0#_
MZ_E7@`P`1.QF`#B</0!8%R/`*!@CP`+_WO]'8>#`*'B@P"AY@,`H>F#`*'M`
MP"A\(,`H?0``)N0"%0!WP,`H8P#!`B```$P8]Q$`&`])`#D'P`)X`P`E]^80
M`/_#_U,7`!4`_[O_4QD`%0#_>_]38T#]`F&@PBEW@,(I>&#"*=<!`!KLPL@H
MC`$`)F4@P`*8`!4`;"#"*?\C^5>`.`!$;!@`).X!`!2-```4C+D4`(R!0`"-
M#0!830$`%(T=`%P%"(`"!`,5`/\3^E>$!$`"``@`4`0`%0#WPL@H;2#"*.P"
M`":L&0!<8:#"*'>`PBAX8,(H8\#"`B```$S_/_A78P#]`F'@PBEWP,(I>*#"
M*7F`PBEZ8,(I>T#"*=@!`!H,P\@HC`$`)FP@PBF`$`!`C```*)<`%0"`-0!$
M&,/(*&T@PB@,`P`FK!D!7&'@PBAWP,(H>*#"*'F`PBAZ8,(H>T#"*&,`PP(@
M``!,_^_X5YD`%0"?R/]#)`,5`/^?]U>`J`!`C$P`*II,P`*,2;\"@`T`1$P'
M`"J?X?]#C$P`*HQ)OP*`F0!`Y`(5`/]_^5>;`!4`1`,5`/]S^5=D$Q``A`B`
M`O\G]U>%```:1P,5`.8"%0"EX/0"F@`5`/^_^%=E(,`"1`,5`/_3^%<,_+\"
MC!P`6&P8`"3N`0`4C0``%(RY%`",@4``C4T`6$0#%0#_Z_=71`,5`/^S^5<D
M`Q4`__OV5Y]@_T<D`Q4`_R_Y5^0"%0#_U_97_P?_4TP'`"J,2;\"GV7_1TP+
M`"J?+?]#_UO_4T0#%0#_J_Y7_[O_4__;]E=C@/X"86#!*7=`P2EX(,$I>0#!
M*7K@P"E[P,`I?*#`*7V`P"E^8,`I?T#`*=@!`!H,P\@HC`$`)JT``"BY`!4`
M;"#`*0ST@`*7`!4`K`D`7+D$P`(D`Q4`_V_X5YL`%0!E$,`"Y`(5`/^W_%>:
M`!4`@!@!0/]3^%>;\`!L?00`)-P!`!J]#T$`[0(`*.P"%0`.](`"H*$!0*X1
M`%B-!0`HC`7``K_U_T>,71$`C6/)*+H!`"9D"\`"A+`0`/_+]5=$=QPX@&0`
M0)QCR2B-`P`F[`(`*.0&P`*N=0PX#_2``LP!`"F`&0!$`)@`4(P``"B$!,`"
MK`4`*8")`$#-`14`S@7``H_I_U\,](`"K`$`*:X%P`(,`!4`+3,`.,TQ$#B,
M!<`"O_7_1QC#R"AM(,`H#`,`)JP5`5QA8,$H=T#!*'@@P2AY`,$H>N#`*'O`
MP"A\H,`H?8#`*'Y@P"A_0,`H8X#!`B```$P,`!4`+3,`.$TS$#B,!<`"O_7_
M1_^O_U/-`14`_X?_4]P!`!J,8\DHGP$`)NP#`":`I0!`[`,5`!H`%0"-(<`H
M3@,5`(PAP`):!X`"O_'_1\X-@`+$#4$`S`$`&HS!RP*-`0`DH$4`1`T$@`*-
M`0`E_Z_T5YX`%0"?2/]#70]!`*8#%0#E`Q4`_P?T5XQCR2B>`0`G3`>``HP-
M00#`,QPX>A"`*?]__E.%`!4`Y`,5`/^/]5>,8\DHA`$`)YX`%0"?`/]#70]!
M`/_/_U,,`!4`_W?^4P1`@`(:`!4`_W__4_^/]%=CP/\"82#`*7<``"?7`0`:
M[(+**(0)##@'`0`:Q@$`&H4``!KGX/D"QN#)**4`]0+_J_17]X+**.0*##AA
M(,`H=P``)H@``!H(0<,"1@``&H4``!H)`!4`!P$5`,9@[`*E@/4"8T#``O_#
M\U/,`0`:C('**(0)##@'`0`:Q@$`&H4``!KGX/D"QN#)**4`]0+_2_138X#_
M`BX``!1Y```G86#`*7=`P"EX(,`I8[@1`&``P"ECN!$`8`#`*6.`_P+9`0`:
M+,/(*(P!`":W__\5]Z*_`VP8("?_\_)73```%(R!@`.,W1``EXT0`(@``!J&
M```:)0``%(<`%0`(X?4"Q@#V`J4$@`/D`A4`_Z_R5PS\OP*,\`!8+```%(3E
M`&C8__\53```%!C#OP.,@8`#C.$0`)B-$`#D`A4`)@``%`4#%0#_M_)7EX!`
M`."Z`&#D!H`"_^?R5XP`%0"`J`!`F`P`;(W<$``-FP!HS?__%4X``!2MP;\#
MSH&``\ZU$`#-C1``K'4`:"T``!2M!8`#MW$`:,7__Q5-```4I<"_`ZV!@`.M
ME1``A`$5`.8"%0"EC1``_R?R5XP`%0"`7!`X.</(*&X8("8M`P`FS4$`7$T`
M`!2M@8`#8[00`&%@P"AW0,`H>"#`*'D``":$`14`8X#``B```$RMW1``C8W_
M;P``*@`,`!4`_[O_4_]_\E?_A_Y38\#^`BX``!1_```G82#!*7<`P2EXX,`I
M><#`*7J@P"E[@,`I?&#`*7U`P"E^(,`I8[@1`&``P"ECP/T"MP`5`-X!`!K,
MP\@HC0$`)L7__Q4L```4I="]`XQ!@@.9`!4`C)40`(0``!J%C1``A&#V`FV(
M$"?_2_A7F``5``6\@`(D`Q4`_P/T5X!D`$"$```:A*#V`B4#%0#_"_M7)`,5
M`-[#R"AMB!`FS`,`)JS1`5PM```4K4&"`V.T$`!A(,$H=P#!*'C@P"AYP,`H
M>J#`*'N`P"A\8,`H?4#`*'X@P"A_```F8T#!`B```$SD`A4`_Y?R5YL``!IE
MX_8"_VOR5Y<`%0"?B/]#VO__%2P``!1:X[\#C$&"`XSI$`":C1``[`(`*)T`
M`!J<```:O0/W`IPC]P*`P0!``!<`0.4"%0`$`Q4`_V/R5X"0`$#D`A4`_Q?S
M5XS\_P+LLA``GP`5``Z\@`+L%@!H`"0`4(`!`"F,_?\"[`X`6(T!`"BN\?];
MY`(5`/_C\E>?`!4`)`,5`/_7\E>$_!``A`3``@S\OP.$[?YK*0,5`*@#%0#G
M`A4`A@,5`"4``!1$`Q4`_^OO5X0$@`(L```4A$T`;```*@`,!P`J@#$`1&7C
M]@($`!4`_X?Q5Y<`%0"?I/Y#[`(`*)])_T<`$P!`#`,`*HQ)OP*?T?]#EP``
M&A\$@`+W0O8"_W__4\7__Q4L```4I>"]`XQ!@@.,E1``A8T0`$0#%0#_Q_%7
MGZ3_1VP8`"3N`0`4#0$`%(RY%`",@4``C8W_7P4$@`)$`Q4`_[_Q5Y]\_T>$
M```:10,5`(2@]@+_-_E71`,5`/\3\5?_*_Y3__OO5V/`_P)A(,`I=P``)P6\
M@`*7`!4`_P/P5X`(`$"7!,`"82#`*.0"%0!W```F8T#``O_7\%-C@/\"+@``
M%'D``"=A8,`I=T#`*7@@P"ECN!$`8`#`*6/`_P+9`0`:+,/(*(P!`"9L"!`G
M@/0`0(P``"B8`!4`@.D`0/]O\5>$!,`"+```%(0=`6C7__\5+```%/?BOP.,
M08`#C-T0`)>-$``%`Q4`Y`(5`/]/[E?D`A4`_S?Q5XS\_P+LLA``#KR``N0"
M%0#L%@!H`!@`4(`!`"F,_?\"A`T`6(T!`"BN\?];U___%2P``!3WXK\#C$&`
M`XS=$`"7C1``!;R``N0"%0#_%^]7@%@`0.22`&C$__\5+```%(3@OP.,08`#
MC)$0`(2-$`#_X^]7.</(*&T($"8L`P`FK'4`7"T``!2M08`#8[00`&%@P"AW
M0,`H>"#`*'D``"9C@,`"(```3#G#R"AM"!`F+`,`)JQ!`%PM```4K4&``V.T
M$`!A8,`H=T#`*'@@P"AY```FA```&H1`]@)C@,`"_W/O4X```"G_<_]3!``5
M`/^'_U/_3^Y78X#^`F%@P2EW0,$I>"#!*7D`P2EZX,`I>\#`*7R@P"E]@,`I
M?F#`*=@!`!H,P\@HC`$`)ID``!IW$,`";"#`*3E#]P+:`0`:Y0(5`"0#%0#_
M0_17@$0`0$QCR2AM!``DCP$`)JT-00#LM1``CB'`*.XU'#C?U?]#C4'`*(PA
MP`*-`0`GO_7_1^4"%0`D`Q4`_P/T5Y_$_T>9```:.8/W`MH!`!KE`A4`)`,5
M`/_G\U>`1`!`3&/)*&T$`"2/`0`FK0U!`.RU$`".(<`H[C4<.-_5_T.-0<`H
MC"'``HT!`">_]?]'Y0(5`"0#%0#_I_-7G\3_1YD``!HYH_<"V@$`&N4"%0`D
M`Q4`_XOS5X!$`$!,8\DH;00`)(\!`":M#4$`[+40`(XAP"CN-1PXW]7_0XU!
MP"B,(<`"C0$`)[_U_T?E`A4`)`,5`/]+\U>?Q/]'F0``&CGC]P+:`0`:Y0(5
M`"0#%0#_+_-7@$0`0$QCR2AM!``DCP$`)JT-00#LM1``CB'`*.XU'#C?U?]#
MC4'`*(PAP`*-`0`GO_7_1^4"%0`D`Q4`_^_R5Y_$_T>9```:.@/X`ML!`!KE
M`A4`1`,5`/_3\E>`1`!`;&/)*&T$`"2/`0`FK0U!`.RU$`".(<`H[C4<.-_5
M_T.-0<`HC"'``HT!`">_]?]'Y0(5`$0#%0#_D_)7G\3_1YH``!I:0_@"VP$`
M&N4"%0!$`Q4`_W?R5X!$`$!L8\DH;00`)(\!`":M#4$`[+40`(XAP"CN-1PX
MW]7_0XU!P"B,(<`"C0$`)[_U_T?E`A4`1`,5`/\W\E>?Q/]'F@``&EMC]@+<
M`0`:Y0(5`&0#%0#_&_)7@$0`0(QCR2AM!``DCP$`)JT-00#LM1``CB'`*.XU
M'#C?U?]#C4'`*(PAP`*-`0`GO_7_1^4"%0!D`Q4`_]OQ5Y_$_T>;```:?(/X
M`MT!`!KE`A4`A`,5`/^_\5>`1`!`K&/)*&T$`"2/`0`FK0U!`.RU$`".(<`H
M[C4<.-_5_T.-0<`HC"'``HT!`">_]?]'Y0(5`(0#%0#_?_%7G\3_1YP``!J=
MP_@"W@$`&N4"%0"D`Q4`_V/Q5X!$`$#,8\DH;00`)(\!`":M#4$`[+40`(XA
MP"CN-1PXW]7_0XU!P"B,(<`"C0$`)[_U_T?E`A4`I`,5`/\C\5>?Q/]'G0``
M&KT#^0+>`0`:Y0(5`*0#%0#_!_%7@$0`0,QCR2AM!``DCP$`)JT-00#LM1``
MCB'`*.XU'#C?U?]#C4'`*(PAP`*-`0`GO_7_1^4"%0"D`Q4`_\?P5Y_$_T>=
M```:O:/V`KX!`!KE`A4`I`,5`/^K\%>`1`!`S&/)*&T$`"2/`0`FK0U!`.RU
M$`".(<`H[C4<.-_5_T.-0<`HC"'``HT!`">_]?]'Y0(5`*0#%0#_:_!7G\3_
M1V0``!KE`A4`A$#Y`O]7\%>%`!4`@`P`0(3#^`+_*_-79```&N4"%0"$H/D"
M_S?P5X4`%0"`$`!`9```&H0`^@+_!_-79```&N4"%0"$0/H"_Q/P5X4`%0"`
M5`!`1&/V`O_G\E<8P\@H;2#`*`P#`":L80!<86#!*'=`P2AX(,$H>N#`*'O`
MP"A\H,`H?8#`*'Y@P"@D`_@">0#!*&4``!JEX/H"8X#!`O^?\E-D```:Y0(5
M`(2`^@+_J^]7A0`5`)^D_T-D@_@"_W_R5_^;_U/_2^E78X#_`F%@P"EW0,`I
MMP$`&NS"R"B,`0`F9```&F40P`*$@/@";"#`*?]G[U>`-`!`A```*(`L`$"$
M0/\"!)`2`/?"R"AM(,`H[`(`)JP=`%QA8,`H=T#`*&.`P`(@``!,!``5`/_?
M_U/_W^A78X#^`F%@P"FM`0`:K`$`&F6@P"EFP,`I9^#`*6@`P2EI(,$I:D#!
M*6M@P2FMP<@HC&'***T!`":%`!4`A`$`)F:@P`)M(,`I9@``)_\/ZU<$_(,"
M_T?J5V,`_P(,`@`4+@``%&RP$0!AX,`I=\#`*7B@P"EY@,`I>F#`*7M`P"E\
M(,`I?0``)V.X$0!@`,`I;/C_7V/`_P*8`!4`N@$`&DS#R"B,`0`F#0(`%*TA
M@`,&"(`"!0`5`*P-'#C_#^A7E_S_`NW^20"MP44`[+80`(P!SP",M1$`][(1
M`.#^`&#]_?\5#`(`%+W#OP.,08`#C/40`!G\OP*=C1``&QR``KP!`!H&`!4`
MY0(5``0#%0#_N^=7F=@`6`8"`!3&((`#I0,5``0#%0#_4^A7A(!``)FP`%AD
MFP!LC.#_`JRS$`"=C0!HCP/``@`,`%",_?\"G7T`:(X!`";M`0`FS?'_7^W]
M_Q4.`@`4K<&_`\Y!@`/.M1``S8T0`(RU$0"$W1``#`(`%(PA@`-:P\@HC0T,
M.$P#`":L90!<#0(`%*U!@`-CM!``8>#`*'?`P"AXH,`H>8#`*'I@P"A[0,`H
M?"#`*'T``"9C`,$"(```3`S^_Q7WLA``[#+_7P3\OP+_I_]39```&H1`^P+_
M&_Y79```&H0`^P+_#_Y7_^/F5V/`_P)A(,`I_V?F5X2`0`#_#^A7@`@`0(0`
M`"9A(,`H8T#``B```$QC`/\"8>#`*7?`P"EXH,`I>8#`*7I@P"E[0,`IMP$`
M&NS"R"B,`0`F>@``&ID`%0!E$,`"1(/[`FP@P"G_P^Q7@$P`0(P``"B8`!4`
M@$$`0"4#%0#_\^97@&P`0/?"R"AM(,`H[`(`)JRQ`%QAX,`H=\#`*'B@P"AY
M@,`H>F#`*'M`P"AC`,$"(```3/?"R"AM(,`H[`(`)B4#%0"L?0!<8>#`*'?`
MP"AXH,`H>8#`*'M`P"A$@_L">F#`*&,`P0+_(^]3)`,5`/_?YU>;`!4`!`,5
M`/_3YU=DDQ``A`C``O^'Y5=G```:90``&@@#%0"E(/<"Y^#V`B8#%0"8`!4`
M_Q?G5_?"R"AM(,`H[`(`)@4#%0"LC?];_Y_E5V/`^0)A(,8I=@#&*7?@Q2EX
MP,4I>:#%*7J`Q2E[8,4I?$#%*7T@Q2E^`,4I?^#$*;D!`!JL`0`:C`'``BW#
MR"BS`0`FDD'`*)%AP"B0@<`HCZ'`*([!P"B-X<`H;```&HSA^P)L0,`I;```
M&HQ!]@)L8,`I;```&HP!_`)X,,`">P``&FR@P"EL```:F@`5`(PA_`(%`Q4`
M9&/V`G.@Q"E@@,`I<@#!*7$@P2EP0,$I;V#!*6Z`P2EMH,$I;,#`*6#@P"G_
M'^M7@!``0(P``"B7`!4`@`D$1/]3Y%>$@$``__OE5X#X`4"7```FX/(!0.0"
M%0#_E^97A`1!`(0$P`+_2^17Y@(`*)T`%0"<`!4`P"P`0'X``!K>8_P"QH!G
M`*0#%0#%`Q4`_]/E5^8&`"B]"\`"]P;``M_D_T=D```:?0#!`H0`^@(`$`!0
MI"/`*+TCP`*`-`!`!0,5`/^'ZE>7`!4`G^C_0XP``"B?X?]#_V/K5Y_8_T/D
M`A4`_R_E5Y<`%0"`,`!$?4#``K<#`";@)@!`[`(`*(`]`4#D`A4`_S/K5X`8
M`42W(\`HO2/``O_F_T?D`A4`_]/E5Y\`%0"$`Q4`_\?E5_\3$`#_$Y`"Y`,5
M`/]WXU=^```::```&F4``!J)`Q4`"('\`L<#]P+F`A4`I:#\`IT`%0#__^17
M!0"'`J0#%0#_X^57#/R_`HP4`%S_-^57B```)`Q$@`(,F0)<9<#!`J0#%0#_
M[^-7EP`5`(`<`$1L@``D[@$`%(T``!2,N10`C(%``(WY`%BL`0`:C&'**$8#
M`":$`0`F90``&J<#%0"EX/T"_V_C5QP`%0`YP\@H;:#$*"P#`":LL0-<82#&
M*'8`QBAWX,4H>,#%*'F@Q2AZ@,4H>V#%*'T@Q2A^`,4H?^#$*(0#%0!\0,4H
M8T#&`B```$SD`A4`_^OC5Y<`%0"](\`"G\#^0__G_E,7`!4`_]_^4V2@P"A\
MH,`"@"0`0`4#%0#_]^A7@`P`0(P``"B`,0!$A"/`*)PCP`*?Y/]'!#2``O\_
MXE=W```:G0`5`)P`%0#WPOL"!DR!`O_S_5/_@^-7EP`5`)_,_T/_5^17A`1!
M`(0$P`+_P_U3?(@`)/_CX5>,@$``C`/_7VR``"0-`(<"C/U'`XWQ_E_D`Q4`
M_^/A5YP`%0!D```:!0,5`(1`_P+_9^A7A0`5`("D`4!$`P`F_YOO5Y8`%0"`
ME`%`Q`(5`/_OXU>?@$``#`R``I\U`&3D\_\"90``&J5@_P+$DA``_P_C5X`<
M`$0,$(`"["\"6/_OOP+-?@`X#+R``JP=`EAZ```:!0,5`$2#^`+_^^=7@$0!
M0(P``"B`/0%`#<"``HTU`5AE```:I>#Z`D2#^`+_N^I7_\O@5W@``!IE```:
M"4/#`H@`%0#'`_<"I@,5`*4@P`*$`Q4`>@``&O_#XE<?_+\"%D2``AA#PP+>
M`_<"6F/``@`X`%#_]^)7C```))8]`%S_>^!7]P:``H@`%0`*`Q4`Z0(5`,<#
M%0"F`Q4`10,5`(0#%0#_=^)7!0"'`H0#%0#_6^-7G\#_6Z0#%0#_C^-79&/V
M`H4#%0#_'^I7A`,5`/\W^E?_P_U3K`$`&HQARBA&`P`FA`$`)F4``!JG`Q4`
MI>#\`O\'X5?_F_U3_POZ5SG#R"AMH,0H+`,`)JQ%`5QA(,8H=@#&*'C`Q2AY
MH,4H>H#%*'M@Q2A\0,4H?2#%*'X`Q2A_X,0HY`(5`'?@Q2AC0,8"_X?A4U8#
M`";_;_Y3!0`5`,0"%0#_8^)7F``5`)_`_D/_U_=7GP`5`("T_F.%V/\"!@`5
M``0#%0#_+^!7=L##`@88@`+%`A4`!`,5`/_+X%<,&(`"C+P`7&WP`"2,@H84
MC`&,`ZQY_E_-$D`JC```%(PAE0.L:?Y?!@`5`.4[_P($`Q4`_^/?5W?@PP(&
MH(`"Y0(5``0#%0#_?^!7#*"``HQP`%QI```:90``&BE!PP+H`A4`QP/W`J8#
M%0"EX/\"A`,5`&"`!"G_#^%7_ZO^4UHCP"A?Y_U#1`,5`/^+X5<,#(`"A-7]
M;X3P_P)E```:I8#_`D23$`#_K^!7UA(3`$23$P#6$A4`_[/]4_]KWU=D```:
MA*#_`O^']E=C`/\"8>#`*7?`P"EXH,`I>8#`*7I@P"E[0,`IN0$`&BS#R"B,
M`0`FMP$`&GH0P`)L(,`I[(+**)@)##AD```:10,5``S#`BJ$`/@"#,<"*?]3
MY5>`$`!`C0``*`S$@`*LD0%8_Z_P5^R"RBB8"0PX90``&@0#%0`'#(`"!@2`
M`J7`P`+_1^!7F``5`(`T`$",0,`H[8+***0)##B%`0`F9@``&L;@P`+_X]Y7
M#$/`*(4!`":L#``DC%G6`(!Y`43L@LHHA`D,.&4``!H'#(`"!@2``J4`P0+_
M\]]7FP`5`(`P`$!D```:10,5`(2@]@+_L^17A@`5`(`$`4!L0\`H[8+***0)
M##B%`0`F_W_>5[@!`!H8P\L"[(+**)L)##AE```:!@2``J4@P0)D`Q4`_RO?
M5V8``!J%`!4`QH#!`F0#%0#_1]Y7]X+**.P*##AD```:10,5`(#%`BF$8/8"
M_T/D5P1#P"F`;`!`!0"'`O\[X%>-!(`"#`2``HTI`&P,1(`"C"``6`PCP"@&
M0\`HAP`5`(4!`"9D```:A$#"`O_+W%<YP\@H;2#`*"P#`":LO0!<8>#`*'?`
MP"AXH,`H>8#`*'I@P"A[0,`H8P#!`B```$P$(\`H_^OW5P1#P"F?C/]'9```
M&H2@P0+_?]Q7C`0`*)]]_D/_;_Y3_VOI5Y@`%0"`0`!`;$/`*.V"RBBD"0PX
MA0$`)@8#%0#_;]U7!`,5`+@!`!K_P]]7&,/+`O_K_E/L@LHHA`D,./]_W%?_
M@_Y3N`$`&AC#RP(.(\`H;4/`*.R"RBC&`0`FI0$`)H0)##C_)]U7_[/^4__O
MW%=C0/\"8:#`*7>`P"EX8,`I>4#`*;<!`!KLPL@HC`$`)I@`%0!D```:91#`
M`H2`^`)L(,`I___B5X`@`$",```H@!D`0`W`@`*-$0!8``\`0`P#`"B`+0!$
M]\+(*&T@P"CL`@`FK($`7&&@P"AW@,`H>&#`*'E`P"ACP,`"(```3`0#%0#_
MI^Q7!;R``ID`%0#_>]Q7@`@`0)D$P`(D`Q4`_UO=5V4``!H&$(`"I8#\`O_K
MW%>?I/]']\+(*&T@P"CL`@`FK"$`7&&@P"AW@,`H>4#`*`0#%0!X8,`H8\#`
M`O_3XU/_!]Q78T#U`F&@RBEW@,HI>&#**:H!`!I,P<@HC`$`)FX@P`+E`0`4
M;"#**9'@P`*&X,$"T@$5`*4`O`,4_@$4,`(`)BT"`"0Q(L`"#X)%``RB10#S
M84$`$.)%`(R5%`",014`K3$``'`"WP#O(4$`K<%,`(Q!%0#OT10`K0'?`(P]
M%0!-`@`G3"+`*5)"P`+1L/]?9L#!*&7@P2AM`,(H=&#`*'.`P"ARH,`H<<#`
M*'#@P"AH`,$HR0'(`@`(`%#H`14`SP'!*,P!`":G`14`SB'``NRQ%0",F14`
MC-$5`(T%00",?44`K3$5`*T!WP#-X<$II@`5`'0"%0#E`!4`4P(5`#("%0`1
M`A4`$`$5`,FQ_U^2```F9B#`*(Y`P"B/8,`HD"#`*)&`P"CM!+44K66F`TQN
M10!4%D$`E#(5`,:T$`#3O14`!0I%``QZ00#&Q!``E`+?`(P5%0!SPA0`E)H0
M`&9`P"B%`=\`<[X5`)3.$`#3E14`E`+?`'/*%`#&M!``QKP0`(<600");D4`
M<[H5`'.:$`#F)!4`2PI%`$AZ00!SFA``9F#`*`@M%0",H14`C-$4`,:T$`!S
M`M\`QK@0`(R5%0!I%D$`:VY%`(=Z00",F1``E`I%`&:`P"CG4!4`-"T5`(S1
M$``4G14`QK00``@!WP"4SA0`C`'?`,64$`"4HA4`B15!`(MM10!F>D$`E)80
M`',*10!EH,`HQDP5`#,M%0"4SA``\Y@5`)0"WP#G`-\`<[(4`*6T$`"EH!``
MB19!`(MN10!SGA4`B'E!`(P)10`(,14`<Y80`"PM%0!SLA``90+?`'/`P"C,
MH!4`C-$4`,8`WP!SMA``<YX0`*D400"K;$4`C)D5`(S-$``S+14`C,T0`(=Z
M00"4"D4`YU`5`)0!WP!LX,`H$YT5`'.6%``(`=\`C+40`(R9$`")%D$`BVY%
M`'.B%0!SLA``+"T5`'.R$`"F>$$`I0A%`,84%0!E`M\`<P#!*.R8%0",T10`
MYP#?`'.V$`!SHA``J11!`*ML10",G14`C,T0`#,M%0",S1``B'I!`)0*10`(
M414`E`'?`&P@P2C3H!4`<Y84`,8`WP",M1``C)T0`(D600"+;D4`<YH5`'.R
M$``L+14`<[(0`*=X00"E"$4`YQ05`&4"WP!S0,$H#)T5`(S1%``(`=\`<[80
M`'.:$`"I%$$`JVQ%`(RA%0",S1``,RT5`(S-$`"&>D$`E`I%`,90%0"4`=\`
M;&#!*/.8%0!SEA0`YP#?`(RU$`",H1``B19!`(MN10!SGA4`<[(0`"PM%0!S
MLA``J'A!`*4(10`(%14`90+?`'.`P2C,H!4`C-$4`,8`WP!SMA``<YX0`*D4
M00"K;$4`C)D5`(S-$``S+14`C,T0`(=Z00"4"D4`YU`5`)0!WP!LH,$H$YT5
M`'.6%``(`=\`C+40`(R9$`")%D$`BVY%`'.B%0!SLA``+"T5`'.R$`"F>$$`
MI0A%`,84%0!E`M\`<\#!*.R8%0",T10`YP#?`'.V$`!SHA``J11!`*ML10",
MG14`C,T0`#,M%0",S1``B'I!`)0*10`(414`E`'?`&S@P2C3H!4`<Y84`,8`
MWP",M1``C)T0`(D600"+;D4`<YH5`'.R$``L+14`<[(0`*=X00"E"$4`YQ05
M`&4"WP!S`,(H#)T5`(S1%``(`=\`<[80`'.:$`"I%$$`JVQ%`(RA%0",S1``
M,RT5`(S-$`"&>D$`E`I%`,90%0"4`=\`;"#"*/.8%0!SEA0`YP#?`(RU$`",
MH1``B6Y%`(@600!SGA4`JWA!`'.R$`"E"$4`#"45`&A`PBAE%14`<[(0`,R4
M%0!S`M\`"+40`,8`WP",T10`!YT0`&EN10!H%D$`C)D5`(R=$``')14`:6#"
M*(AZ00"4"D4`"%$5`(R=$`",`=\`M*`5`"FU$`"+;44`I0#?`)3.%`"'%4$`
M)ID0`)26%0#G+!4`E)H0`.<`WP!F>D$`<PI%`)2>$`#&3!4`:X#"*(D"WP`3
MF14`<[(4``@!WP`G%4$`-VU%`&NU$`!MHA4`\UP5`(=Y00","44`YS`5`&65
M$`#,G!4`K940`',"WP",T14`=*#"**7-$`#-L]T4K86N`ZL`WP!W;44`E+80
M`',500"4HA``<UX5`(P!WP",T1``<P+?`)/-$``H>4$`;,#"*"D)10`()14`
M]*`5`&D"WP`W;44`C+40`,8`WP"%EA4`-!5!`(R9$`"E`-\`E%X5`(R5$`"4
M`M\`E-$0`&9Y00!LX,(H:PE%`,8L%0`%F14`BP+?`'=M10",M1``YP#?`*7,
M%0!S%4$`C)T0`*4`WP!S7A4`C)40`',"WP"3S1``)WE!`&P`PR@I"44`YR05
M`,6<%0!I`M\`-VU%`(RU$``(`=\`I=`5`#0500",H1``I0#?`)1>%0",E1``
ME`+?`)31$`!E>4$`;"##*&L)10"E+!4`B`+?`.N4%0#7`-\`C+40`&;-%0`+
M;44`$Q5!`(S=$`#&`-\`<RX5`(R9$`!S`M\`D\T0`"9Y00!L0,,H*0E%`,8D
M%0"KF!4`:0+?`/<`WP",M1``9]$5`"MM10`T%4$`C-T0`.<`WP"4+A4`C)T0
M`)0"WP"4T1``!WE!`&Q@PR@("44`YR`5`,N<%0"(`M\`MP#?`(RU$`!ES14`
M"VU%`!,500",W1``I0#?`',N%0",E1``<P+?`)/-$``E>4$`;(##*"D)10"E
M)!4`ZY05`&D"WP#7`-\`C+40`&;1%0`K;44`-!5!`(S=$`#&`-\`E"X5`(R9
M$`"4`M\`E-$0``9Y00!LH,,H"`E%`,8@%0"KF!4`B`+?`/<`WP",M1``9\T5
M``MM10`3%4$`C-T0`.<`WP!S+A4`C)T0`',"WP"3S1``)WE!`&S`PR@I"44`
MYR05`,N<%0!I`M\`MP#?`(RU$`!ET14`*VU%`#0500",W1``I0#?`)0N%0",
ME1``E`+?`)31$``%>4$`;.##*`@)10"E(!4`ZY05`(@"WP#7`-\`C+40`&;-
M%0`+;44`$Q5!`(S=$`#&`-\`<RX5`(R9$`!S`M\`D\T0`"9Y00!L`,0H*0E%
M`,8D%0"KF!4`:0+?`/<`WP",M1``9]$5`"MM10`T%4$`C-T0`.<`WP"4+A4`
MC)T0`)0"WP"4T1``!WE!`&P@Q"@("44`YR`5`,N<%0"(`M\`MP#?`(RU$`!E
MS14`"VU%`!,500",W1``I0#?`',N%0",E1``<P+?`)/-$``E>4$`;$#$*"D)
M10"E)!4`ZY05`&D"WP#7`-\`C+40`&;1%0`K;44`-!5!`(S=$`#&`-\`E"X5
M`(R9$`"4`M\`E-$0``9Y00!L8,0H"`E%`,8@%0"KF!4`B`+?`/<`WP",M1``
M9\T5``MM10`3%4$`C-T0`.<`WP!S+A4`C)T0`',"WP"3S1``)WE!`&R`Q"@I
M"44`YR05`,N<%0!I`M\`MP#?`(RU$`!ET14`*VU%`#0500",W1``I0#?`)0N
M%0",E1``E`+?`)31$``%>4$`;*#$*`@)10"E(!4`ZY05`(@"WP#7`-\`C+40
M`&;-%0`+;44`$Q5!`(S=$`#&`-\`<RX5`(R9$`!S`M\`D\T0`"9Y00!LP,0H
M*0E%`,8D%0!K`M\`J9@5`'=M10",M1``YP#?`"G1%0!T%4$`C)T0`"D!WP"4
M7A4`C*40`)0"WP"4T1``!WE!`&S@Q"@("44`YR`5`,F<%0"(`M\`C+40`*4`
MWP`SS14`%VU%`(R5$`!S`M\`!15!`(S-$`"S7!4`C,T0`&EY00!S`,4H:PE%
M`"DM%0#KI!4`A0'?`'.V$`#&`-\`;=$5`'.:$`"T%$$`IFQ%`*T!WP`,>4$`
M"`E%`(PA%0!SMA``:"#%*(T:%0!T-QX5E'*S`Q0``!:&`=\`<[80`"TQ%0!S
M`M\`*YD4`*V5%``(T1``YP#?``B=$`!W;D4`K2T5`*=X00!K%D$`I0A%`.<4
M%0"MH1``95T5`*V5$`"H`=\`;4#%*(P=%0#EF!0`*0'?`(S-%`"MT1``K:40
M`(P5%0`);44`!15!`&MZ00",M1``<PI%`*TD%0!I8,4H<TT5`&4"WP",M1``
M[4P5`(P!WP#KE!0`K:$4`"G1$``IF1``EVU%`*TM%0`&>4$`BQ5!``@)10#&
M(!4`K:40`&A=%0"MH1``J`'?`&V`Q2AS&A4`R904`*W1$`!SLA0`YP#?`',F
M%0"GG1``"15!``MM10"->4$`C`E%`*TQ%0!LGA``,RT5`&F@Q2BG`=\`C,T0
M`-,T%0",`=\`RYP4`'.B%``IT1``*940`)=M10!S+A4`!7E!`(L500`("44`
MI2`5`'.F$`!H714`<Z(0`&@"WP!SP,4HK145`*F<%`!STA``K;$4`,8`WP"M
M)14`9IH0``D500`+;44`DWE!`(P)10!S,A4`K)D0`"TM%0!IX,4H9@+?`(RU
M$`"M3!4`C`'?`*N8%`"MH10`*=$0`"F=$`"7;44`K2T5``=Y00"+%4$`"`E%
M`.<@%0"MI1``:%T5`*VA$`"H`=\`;0#&*',>%0#IF!0`K=$0`'.R%`"E`-\`
M<R85`*65$``)%4$`"VU%`(UY00","44`K3$5`&R6$``S+14`:2#&**4!WP",
MS1``\S05`(P!WP#KE!0`<Z(4`"G1$``IF1``EVU%`',N%0`&>4$`BQ5!``@)
M10#&(!4`<Z80`&A=%0!SHA``:`+?`'-`QBBM&14`R904`'/2$`"ML10`YP#?
M`*TE%0!GGA``"15!``MM10"3>4$`C`E%`',R%0"LG1``+2T5`&E@QBAG`M\`
MC+40`,U,%0",`=\`RYP4`*VA%``IT1``*940`)=M10"M+14`!7E!`(L500`(
M"44`I2`5`*VE$`!H714`K:$0`*@!WP!M@,8H<Q85`*F<%`"MT1``<[(4`,8`
MWP!S)A4`IID0``D500`+;44`C7E!`(P)10"M,14`;)H0`#,M%0!IH,8HI@'?
M`(S-$`"S-!4`C`'?`*N8%`!SHA0`*=$0`"F=$`"7;44`<RX5``=Y00"+%4$`
M"`E%`.<@%0!SIA``:%T5`'.B$`!H`M\`<\#&**T=%0#IF!0`<](0`*VQ%`"E
M`-\`K245`&66$``)%4$`"VU%`)-Y00","44`<S(5`*R5$``M+14`:>#&*&4"
MWP",M1``[4P5`(P!WP#KE!0`K:$4`"G1$``IF1``EVU%`*TM%0`&>4$`BQ5!
M``@)10#&(!4`K:40`&A=%0"MH1``J0'?`&T`QRAS&A4`R)04`*W1$`!SLA0`
MYP#?`',B%0"GG1``*!5!`"MM10"->4$`C`E%`*TQ%0!LGA``$RT5`&L@QRBG
M`=\`C,T0`-,T%0",`=\`R)P4`'.F%`!KT1``:Y40`)<500"8;44`)0E%`',B
M%0`H>4$`"!45`'.N$`#E8A4`<Y80`,4`WP!F0,<HK2$5`',"WP`)G10`QM`0
M`*VQ%`#%E!``K245`&8600!I;D4`K940`(MY00#%)!4`C`E%`&9@QRAK,14`
MK)40`(P!WP!I`=\`!2T5`!BE%`"7;44`I<P4`,;0$`"-%4$`QIP0`*U=%0"E
M8!4`I9@0`&=Z00"M`=\`9@I%`!,!WP!H@,<HYA@5`*>T$`#E`-\`;1D5`->D
M%`"K;$4`K;$4``C1$`"T%$$`",T0`*U=%0"3+A4`K:$0`',"WP"MS1``B'E!
M`&N@QRB,"44`D\64%0@Q%0!S6H<#$P``%K0!WP#,H!4`EVY%`(R=%0!KS1``
MAQ9!`&NE$`",`=\`Z5P5`(RM$``I`=\`IWA!`*4(10#G%!4`A:40`&G`QRBK
M`-\`#)T5`"G-$`!W;44`C+45`,8`WP!M%4$`)ID0`*U=%0",`=\`C)D0`*T!
MWP"&>D$`E`I%`,90%0"4M1``;.#'*(D"WP#MF!4`-VU%`(S-$``(`=\`I945
M`"T500",H1``I0#?`*U=%0",E1``K0'?`(VU$`!E>4$`;`#(*&L)10"E+!4`
MJ`'?`,N4%0#W`-\`C,T0`&?1%0`+;44`%!5!`(S=$`#G`-\`E"X5`(R=$`"4
M`M\`E-$0`"=Y00!L(,@H*0E%`.<D%0"KG!4`B0+?`-<`WP",S1``9K45`"MM
M10`M%4$`C-T0`,8`WP"M+14`C)D0`*T!WP"-M1``!GE!`&Q`R"@("44`QB`5
M`.N8%0"H`=\`MP#?`(S-$`!ET14`"VU%`!0500",W1``I0#?`)0N%0",E1``
ME`+?`)31$``E>4$`;&#(*"D)10"E)!4`RY05`(D"WP#W`-\`C,T0`&>U%0`K
M;44`+15!`(S=$`#G`-\`K2T5`(R=$`"M`=\`C;40``=Y00!L@,@H"`E%`.<@
M%0"KG!4`J`'?`-<`WP",S1``9M$5``MM10`4%4$`C-T0`,8`WP"4+A4`C)D0
M`)0"WP"4T1``)GE!`&R@R"@I"44`QB05`.N8%0")`M\`MP#?`(S-$`!EM14`
M*VU%`"T500",W1``I0#?`*TM%0",E1``K0'?`(VU$``%>4$`;,#(*`@)10"E
M(!4`RY05`*@!WP#W`-\`C,T0`&?1%0`+;44`%!5!`(S=$`#G`-\`E"X5`(R=
M$`"4`M\`E-$0`"=Y00!LX,@H*0E%`.<D%0"KG!4`B0+?`-<`WP",S1``9K45
M`"MM10`M%4$`C-T0`,8`WP"M+14`C)D0`*T!WP"-M1``!GE!`&P`R2@("44`
MQB`5`.N8%0"H`=\`MP#?`(S-$`!ET14`"VU%`!0500",W1``I0#?`)0N%0",
ME1``E`+?`)31$``E>4$`;"#)*"D)10"E)!4`RY05`(D"WP#W`-\`C,T0`&>U
M%0`K;44`+15!`(S=$`#G`-\`K2T5`(R=$`"M`=\`C;40``=Y00!L0,DH"`E%
M`.<@%0"KG!4`J`'?`-<`WP",S1``9M$5``MM10`4%4$`C-T0`,8`WP"4+A4`
MC)D0`)0"WP"4T1``)GE!`&Q@R2@I"44`QB05`.N8%0")`M\`MP#?`(S-$`!E
MM14`*VU%`"T500",W1``I0#?`*TM%0",E1``K0'?`(VU$``%>4$`;(#)*`@)
M10"E(!4`JP'?`,B4%0#W`-\`C,T0``?1%0!H;44`=!5!`(S=$`#G`-\`E"(5
M`(R=$`"4`M\`E-$0`"AY00!LH,DH*0E%``@E%0"GH!4`B0+?`-<`WP",S1``
MYK05`"=M10`M%4$`C-T0`,8`WP"M'14`C)D0`*T!WP"&M1``9WE!`&W`R2AK
M"44`YRP5``R=%0#+`-\`E-$5`'=M10"MS1``I0#?`&P500"ME1``C%T5`(4"
MWP"ME1``C`'?`*6Q$``T>4$`;.#)*"D)10"4)A4`[=`5`*D`WP",S1``"`'?
M`*V9%0",H1``K0'?`"@500`W;44`C+40``U=%0",M1``;0#**&9Y00!K"44`
MQBP5`*W-$`"3FA4`C`'?`*W)$`#G`-\`<Y85`*V=$`!S`M\`A15!`(=M10`R
M>4$`*0E%`*W-$`!2)A4`LQP5`)#!$`#&O!``K<T0`$ZZ$`",QA``K0'?``\"
MWP",`=\`S@'?`-``WP"-```GC(#`*8\@P"F.0,`ID&#`*4K!R"AM(,HH3`$`
M)JP9`%QAH,HH=X#**'A@RBACP,H"(```3/]SQ5=CP/\"82#`*00`@@+_$\57
M38K.%*T%C`.-```G39O?%:TEK@,-```6C2#`*:UU,16M^;,##0``%HU`P"FM
M9"`4K=F1`XU@P"G-I8<5K<&'`PT``!:-@,`I@*#`*8#`P"F`X($I82#`*&-`
MP`(@``!,8X#]`F%@PBEV0,(I=R#"*7@`PBEYX,$I>L#!*7N@P2E\@,$I?6#!
M*7Y`P2E_(,$IC:#`*([`P"B9`!4`S#0M`(P!WP"-M1(`A'@`),ZU$`#-=$4`
MK;D0`"RCP"DMP\`IV@`5`+P`%0`[X\`"@&P`0!<`@0+W$A$`[()``,PP$@#W
MLA,`.^/``LPP$P#W,A4`9),0`.:"0`"%1`1LC)@0`+B8$`"L*`1HA0,5`/^C
MPU<L>P`D#0"!`HQ=$`".@4``+..!*<W)`UPD`Q4`6E\1`/\OZ%<<`Q4`#/R`
M`IJ-`V0LX\$"F`,5`)<#P0)LX,`I>:#`*7C/`VQLX,`H#-,#:'?`P"D(+P`J
M##L`*@T_`"H.0P`J#T<`*A!+`"H13P`J$E,`*A-7`"H46P`J`1\`*@LC`"H*
M)P`J"2L`*@<S`"H$-P`J%@<`*A\+`"H>#P`J'1,`*AP7`"H9&P`J:```*6P$
M`"EM"``I;@P`*6\0`"EP%``I<1@`*7(<`"ES(``I="0`*05?`"H&8P`J#&<`
M*@UK`"H.;P`J$'<`*A%[`"H2?P`J$X,`*A2'`"H/<P`J92@`*68L`"D%BP`J
M!H\`*FPP`"EM-``I#),`*@V7`"IN.``I#IL`*G!``"EQ1``I<D@`*7-,`"ET
M4``I950`*698`"EL7``I;6``*6YD`"EO/``I#Y\`*A"C`"H1IP`J$Z\`*A2S
M`"H%MP`J!KL`*@R_`"H-PP`J#L<`*A*K`"IO:``I<&P`*0_+`"H0SP`J<7``
M*1'3`"IS>``I='P`*1/C`"H4WP`J98``*6:$`"D%VP`J!M<`*FR(`"EMC``I
M;I``*6^4`"EPF``I<9P`*7)T`"D2YP`J#/\`*A'K`"H0[P`J#_,`*@[W`"H-
M^P`J"`,`*F0W`"ED!``J:`,`*6@``"ID.P`I9`@`*F$?`"EK(P`I9#\`*60,
M`"IJ)P`I:2L`*61#`"ED$``J:"\`*6<S`"ED1P`I9!0`*G8'`"E_"P`I?@\`
M*7T3`"E\%P`I>1L`*61+`"ED&``J9U0`*EH#OP)D3P`I9!P`*A@#P0+W`L$"
M9%,`*60@`"ID5P`I9"0`*F1;`"ED*``J9%\`*60L`"ID8P`I9#``*F1G`"ED
M-``J9&L`*60X`"ID;P`I9#P`*F1S`"ED0``J9'<`*61$`"ID>P`I9$@`*F1_
M`"ED3``J9(,`*610`"IDAP`I9*#`*&>+`"EG6``J9X\`*6=<`"IGDP`I9V``
M*F>7`"EG9``J9YL`*6=H`"IGGP`I9VP`*F>C`"EG<``J9Z<`*6=T`"IGJP`I
M9W@`*F>O`"EG?``J9[,`*6>``"IGMP`I9X0`*F>[`"EGB``J9[\`*6>,`"IG
MPP`I9Y``*F?'`"EGE``J9\L`*6>8`"IL_P`I9M<`*6?/`"EGG``J9=L`*73?
M`"EGTP`I<^,`*7+G`"EQZP`I<.\`*6_S`"EN]P`I;?L`*?^KY%<,_(`"FIG\
M8WF@P"A\P,`H?&L`:)L/`&R,ZQ``;%L`:$8#%0"%`Q4`9`,5`/_+OU<ZXX$I
M86#"*'9`PBAW(,(H>`#"*'G@P2AZP,$H>Z#!*'R`P2A]8,$H?D#!*'\@P2AC
M@,("(```3'?`P"D;0_QO=S_\;P``*@!LZQ``C*?_;P``*@"XF!``I,C[;YC$
M^V\``"H`8T#_`F&@P"EW@,`I>&#`*7E`P"EZ(,`I>P``)[J@P"BYX,`"#P"^
M`DP/10"-_4`#K06``HS]0`.[P,`HKH%``"\S$#@,X(`"MP`5`)@`%0".D0%D
M#`"!`HPU$0`/$(`"+;L0`(]=`FP."(`"CD$";(`U`D3D`A4`_YOC5^#BP"D@
M(\`I($/`*2!CP"D@@\`I(*/`*2##P"EM8T4`#``5`*P!AP!M0T4`K"&/`&TC
M10"L09<`;&.?`$UC10"L@:<`34-%`*RAKP!-(T4`K,&W`$SCOP#LPL$IY`(5
M`/\WXU?L`@`FY`(5`(QA10`,`P`I[`(`)HQ!10`,!P`I[`(`)HPA10`,"P`I
M[`(`)@P/`"GL(L`HC&%%``P3`"GL(L`HC$%%``P7`"GL(L`HC"%%``P;`"GL
M(L`H#!\`*>Q"P"B,844`#",`*>Q"P"B,044`#"<`*>Q"P"B,(44`#"L`*>Q"
MP"@,+P`I[&+`*(QA10`,,P`I[&+`*(Q!10`,-P`I[&+`*(PA10`,.P`I[&+`
M*`P_`"GL@L`HC&%%``Q#`"GL@L`HC$%%``Q'`"GL@L`HC"%%``Q+`"GL@L`H
M#$\`*6&@P"AW@,`H>&#`*'E`P"AZ(,`H>P``)F/`P`+_Q\!3#."``HPU$0`/
M@(`"+;L0`(^1`&P.0(`"CFT`;`X@@`*.30!L#A"``HXM`&P."(`"CA$`;)^%
M_D.@`0`I_W_^4Z`!0"F,^?\"K0G``I]M_D/_Z_]3H`$`)8SQ_P(."(`"K1'`
M`H[1_VO_V_]3H`$`)XSA_P(.$(`"K2'``HZQ_VO_U_]3H`$`)Z`AP"F,P?\"
M#B"``JU!P`*.C?]K_]/_4R`['#B@(<`IH$'`*:!AP"F,@?\"#D"``JV!P`*.
M8?]K_\?_4Z`!`"G_S_U3H`%`*8SY_P*M"<`"G[W]0__K_U,@.Q@XC/'_`@X(
M@`*M$<`"CJ']:__;_U,E<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O
M8R\E:2\E<P``````+@````````!005)?5$5-4```````````4$%27U!23T=.
M04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"````````
M``!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)5
M1P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````
M````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```````````Q````````
M`&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?3$E"4D%265]0
M051(`%-94U1%30``+W1M<`````!54T52`````%5315).04U%```````````E
M,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M```````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````
M````4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9````````"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P``````````&`````````!P97)L`````#``````````4$%2.CI086-K97(Z
M.E9%4E-)3TX`````,2XP-C$```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64`
M```````M+0```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C
M86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N
M<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD
M8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<
M,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM
M>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D
M8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O
M9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D
M<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C
M:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*
M<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P
M+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@
M,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]
M("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z
M)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H
M*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P
M87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U
M=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@
M9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S
M="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&
M2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@
M;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B
M72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O
M<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D
M(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<
M,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H
M92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE
M(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%
M7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD[
M"F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M
M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&
M2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M
M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N
M+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R
M;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A
M;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F
M:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN
M9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]
M("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@
M;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO
M=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q
M(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R
M(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P
M87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T[
M"FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES
M(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,[
M"F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M
M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD
M969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L
M;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L
M("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U
M="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E
M("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R
M:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*
M:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I
M.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D
M;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z
M("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z
M:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M
M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D
M4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS
M92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E
M<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B
M73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY
M("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E
M:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T
M:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L
M("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A
M8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H
M(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A
M8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP
M<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!
M3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!0TA%
M```!&P,[U````!D```"`?O__``4``"B"___L````&(/__R@!``"H@___5`$`
M``R%__^(`0``6(?__]`!``#$A___\`$``.R'__\$`@``:(G__S@"``!LB?__
M3`(``.R+__^8`@``((S__[@"``"8C?___`(``)R2__]``P``")/__V0#``!@
MD___?`,```25___``P``+)7__]P#``!(EO__)`0``(B<__^,!```^)[__\0$
M``#@G___.`4``'2V__]D!0``Y+;__X0%``#0N___T`4````````0````````
M``%Z4@`!?`$!&PT#`#@````8````-('___``````1`Y`8($"EP28!ID(F@J;
M#)P.G1`"?`K!1-A$V43:1-M$W$3=2-=$#@!$"R@```!4````Z('__Y``````
M1`ZP`4R!`I<$F`8";`K!1-=$V$0.`$0+````,````(````!,@O__9`$```!$
M#L`!6($"EP28!ID(F@J;#'0*P4371-A$V43:1-M$#@!$"T0```"T````?(/_
M_TP"````1`Y@:($"EP28!ID(F@J;#)P.G1">$I\4`Q`!"L%$UT381-E$VD3;
M1-Q$W43>1-]$#@!$"P```!P```#\````@(7__VP`````1`X02($"EP1TP437
M9`X`$````!P!``#,A?__*``````````P````,`$``."%__]\`0```$0.(&@.
MP$"9"($"EP28!@,<`0H.($3!1-=$V$392`X`1`L`$````&0!```HA___!```
M``````!(````>`$``!B'__^``@```$0.4'@.X"&?%($"EP28!ID(F@J;#)P.
MG1">$@*`"@Y01,%$UT381-E$VD3;1-Q$W43>1-]$#@!$"P``'````,0!``!,
MB?__-`````!$#A!(@0*7!%C!2-=$#@!`````Y`$``&")__]X`0```$0.(&`.
ML""9"($"EP28!@+L"@X@1,%$UT381-E$#@!$"UP*#B!$P4371-A$V4P.`$0+
M`$`````H`@``E(K__P0%````1`Y@9($"EP28!ID(F@J;#)P.G1">$@.`!`K!
M1-=$V$3:1-M$W$3=1-Y(V4P.`$0+````(````&P"``!4C___;`````!$#B!(
M@0*7!`)("L%$UT0.`$0+%````)`"``"<C___6`````!$#F!$@1(`0````*@"
M``#<C___I`$```!$#D!\#M"`!($"EP28!ID(F@J;#)P.G1`##`$*#D!$P437
M1-A$V43:1-M$W$3=1`X`1`L8````[`(``#R1__\H`````$0.$$2!`EC!1`X`
M1`````@#``!(D?__'`$```!$#D!8@0*7!)@&F0B:"IL,`E0*P4371-A$V43:
M1-M$#@!$"U@*P4371-A$V43;2-I$#@!$"P``9````%`#```<DO__0`8```!$
M#I`#;($"E@27!I@(F0J:#)L.G!"=$IX4GQ8#6`(*P4361-=$V$391-I$VT3=
M1-Y$WTC<1`X`1`L#.`(*P4361-A$V43:1-M$W$3=1-Y$WTC71`X`1`LT````
MN`,``/27__]P`@```$0.0%B!`I<$F`:9")H*FPP#G`$*P4371-A$V43:1-M$
M#@!$"P```#@```#P`P``+)K__^@`````1`XP4($"EP28!ID(`E@*P4371-A$
MV40.`$0+`DP*P4371-E(V$0.`$0+`#0````L!```>'G__QP"````1`Y@5($"
MEP28!ID(F@H#9`$*P4371-A$VDC91`X`1`L`````````*````&0$``"@FO__
ME!8```!$#K`%3($"EP28!@-P%@K!1-=$V$0.`$0+```<````D`0```BQ__]P
M`````$0.$$2!`@)@P40.`````$@```"P!```6+'__^P$````1`Z@`6R!`I8$
MEP:8")D*F@R;#IP0G1*>%)\6`V`$"L%$UD371-A$V43:1-M$W$3=1-Y$WT0.
M`$0+```T````_`0``/BU___8`@```$0.,%B!`I<$F`:9")H*FPP#J`$*P437
M1-A$V43:1-M$#@!$"P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!T(`````````0@`````````0````````#I`@````````$`
M````````]`(````````=`````````"P$````````#```````````````````
M``T````````````````````9`````````!#^````````&P`````````(````
M`````!H`````````&/X````````<``````````@`````````]?[_;P````"`
M`@````````4`````````,`T````````&`````````%@#````````"@``````
M``!*!`````````L`````````&``````````5`````````````````````P``
M``````!(``$```````(`````````<`4````````4``````````<`````````
M%P````````#8$P````````<`````````@!$````````(`````````%@"````
M````"0`````````8`````````!X`````````&`````````#[__]O``````$`
M``@`````^?__;P`````*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````"E!!4BYP;0H``````````(!>````````Z&````````#P
M8````````/A@`````````&$```````````````````AA````````________
M__\``````````%`9````````4!D```````!0&0```````%`9````````4!D`
M``````!0&0```````%`9````````4!D```````!0&0```````%`9````````
M4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9````
M````4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9
M````````4!D```````!0&0```````%`9````````4!D```````!0&0``````
M`%`9````````4!D```````!0&0```````%`9````````4!D```````!0&0``
M`````%`9````````4!D```````!0&0```````%`9````````4!D```````!0
M&0```````%`9````````4!D```````!0&0```````%`9````````4!D`````
M``!0&0```````%`9````````4!D```````!0&0```````%`9````````4!D`
M``````!0&0```````%`9````````4!D```````!0&0```````%`9````````
M4!D```````!0&0```````%`9````````(/X`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````!`=````````````````````````````
M`````````````````````````````````+`"`0``````1T-#.B`H06QP:6YE
M(#$S+C(N,5]G:70R,#(S,3`Q-"D@,3,N,BXQ(#(P,C,Q,#$T```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F1A=&$`+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N=```
M````````````````````````````````````````````````````````````
M``````````````````````````````L````!`````@`````````X`@``````
M`#@"````````'@````````````````````$````````````````````3````
M!P````(`````````6`(```````!8`@```````"0````````````````````$
M````````````````````)@```/;__V\"`````````(`"````````@`(`````
M``#4``````````0`````````"````````````````````#`````+`````@``
M``````!8`P```````%@#````````V`D````````%````"`````@`````````
M&``````````X`````P````(`````````,`T````````P#0```````$H$````
M```````````````!````````````````````0`````0````"`````````(`1
M````````@!$```````!8`@````````0`````````"``````````8````````
M`$H````$````0@````````#8$P```````-@3````````<`4````````$````
M$0````@`````````&`````````!/`````0````8`````````4!D```````!0
M&0```````,`#```````````````````0`````````!``````````5`````$`
M```&`````````!`=````````$!T````````H0```````````````````!```
M`````````````````%H````!`````@`````````X70```````#A=````````
M5T$```````````````````@```````````````````!B`````0````(`````
M````D)X```````"0G@```````-0````````````````````$````````````
M````````<`````$````"`````````&B?````````:)\````````T!0``````
M````````````"````````````````````'H````.`````P`````````0_@``
M`````!"^````````"`````````````````````@`````````"`````````"&
M````#P````,`````````&/X````````8O@````````@`````````````````
M```(``````````@`````````D@````8````#`````````"#^````````(+X`
M``````#@`0````````4`````````"``````````0`````````)L````!````
M`P````````````$```````#`````````2`````````````````````@`````
M``````````````"A`````0````,`````````2``!``````!(P````````&@"
M```````````````````(``````````@`````````I@````$````#````````
M`+`"`0``````L,(````````(````````````````````"```````````````
M`````*T````(`````P````````"X`@$``````+C"````````6```````````
M``````````@```````````````````"R`````0```#``````````````````
M``"XP@```````#$````````````````````!``````````$``````````0``
M``,`````````````````````````Z<(```````"[````````````````````
0`0``````````````````````
